.. vxmessenger documentation master file, created by
   sphinx-quickstart on Thu Oct 22 09:07:50 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst
